@@ -13,23 +13,53 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: enigma.cc,v 1.38 2004/05/27 20:38:28 dheck Exp $
  */
+
+#include "errors.hh"
 #include "enigma.hh"
-#include "px/px.hh"
+#include "ecl.hh"
+#include "main.hh"
 
 #include <iostream>
-#include <cassert>
 #include <ctime>
 #include <set>
 
 using namespace std;
-using namespace px;
+using namespace ecl;
 using namespace enigma;
 
 
+/* -------------------- Game Type -------------------- */
+
+static const char *versionName[GAMET_COUNT+1] = {
+    "enigma", // same indices as enum GameType
+    "oxyd1",
+    "per.oxyd",
+    "oxyd.extra",
+    "oxyd.magnum",
+    0
+};
+
+GameType enigma::GetGameType(std::string name) {
+    GameType type = GAMET_UNKNOWN;
+    for (int v = 0; v<GAMET_COUNT; ++v) {
+        if (0 == strcmp(name.c_str(), versionName[v])) {
+            type = GameType(v);
+            break;
+        }
+    }
+    return type;
+}
+
+std::string enigma::GetGameTypeName(GameType type) {
+    if (type >= GAMET_FIRST && type <= GAMET_LAST)
+        return versionName[type];
+    else
+        return "unknown";
+}
+
 /* -------------------- Direction -------------------- */
 
 Direction enigma::reverse(Direction d) {
@@ -67,7 +97,8 @@ direction_fromto(GridPos source, GridPos target)
         else if (dx ==  1) d = EAST;
     }
 
-    assert(d != NODIR); // source and target have to be adjacent!
+    ASSERT(d != NODIR, XLevelRuntime,
+        "direction_fromto: source and target not adjacent");
     return d;
 }
 
@@ -152,13 +183,13 @@ void Value::clear() {
 
 double Value::get_double() const throw()
 {
-    assert(type == DOUBLE);
+    ASSERT(type == DOUBLE, XLevelRuntime, "get_double: type not double");
     return val.dval;
 }
 
 const char* Value::get_string() const throw()
 {
-    assert(type == STRING);
+    ASSERT(type == STRING, XLevelRuntime, "get_string: type not string");
     return val.str;
 }
 
@@ -182,35 +213,35 @@ Buffer& enigma::operator<<(Buffer& buf, const Value& val)
     return buf;
 }
 
-Buffer& enigma::operator>>(Buffer& buf, Value& val)
-{
-    Uint8 type = Value::NIL;
-    buf >> type;
+// Buffer& enigma::operator>>(Buffer& buf, Value& val)
+// {
+//     Uint8 type = Value::NIL;
+//     buf >> type;
 
-    switch (type) {
-    case Value::NIL:
-        // ## fixme
-        break;
-    case Value::DOUBLE:
-        {
-            double tmp;
-            if (buf >> tmp)
-                val = Value(tmp);
-        } break;
-    case Value::STRING:
-        {
-            Uint16 len;
-            if (buf >> len) {
-                char* tmp = new char[len+1];
-                tmp[len] = 0;
-                if (buf.read(tmp, len))
-                    val.assign(tmp);
-                delete[] tmp;
-            }
-        } break;
-    }
-    return buf;
-}
+//     switch (type) {
+//     case Value::NIL:
+//         // ## fixme
+//         break;
+//     case Value::DOUBLE:
+//         {
+//             double tmp;
+//             if (buf >> tmp)
+//                 val = Value(tmp);
+//         } break;
+//     case Value::STRING:
+//         {
+//             Uint16 len;
+//             if (buf >> len) {
+//                 char* tmp = new char[len+1];
+//                 tmp[len] = 0;
+//                 if (buf.read(tmp, len))
+//                     val.assign(tmp);
+//                 delete[] tmp;
+//             }
+//         } break;
+//     }
+//     return buf;
+// }
 
 int enigma::to_int(const Value &v) {
     switch (v.get_type()) {
@@ -232,6 +263,10 @@ double enigma::to_double(const Value &v) {
     }
 }
 
+#ifdef _MSC_VER
+#define snprintf _snprintf
+#endif
+
 const char * enigma::to_string(const Value &v) {
     static char buf[30];
     switch (v.get_type()) {
@@ -261,7 +296,7 @@ ostream& enigma::operator<<(ostream& os, const Value& val)
 
 /* -------------------- GridPos -------------------- */
 
-GridPos::GridPos(const px::V2& p) 
+GridPos::GridPos(const ecl::V2& p) 
 : x (round_down<int>(p[0])), 
   y (round_down<int>(p[1])) 
 {}
@@ -279,7 +314,7 @@ std::ostream& enigma::operator<<(std::ostream& os, const GridPos& val)
 */
 GridPos enigma::get_neighbour (GridPos p, int i)
 {
-    assert (i >= 0 && i <= 9);
+    ASSERT (i >= 0 && i <= 9, XLevelRuntime, "get_neighbour: index out of bounds");
     static int xoff[9] = { 0,0,-1,1,0,-1,1,-1,1 };
     static int yoff[9] = { 0,-1,0,0,1,-1,-1,1,1 };
     return GridPos(p.x + xoff[i], p.y + yoff[i]);
@@ -409,24 +444,23 @@ namespace
 
         Font *load_bmf (const string &name) {
             string png, bmf;
-            using enigma::FindFile;
-            if (FindFile (string("fonts/")+name+".png", png) &&
-                FindFile (string("fonts/")+name+".bmf", bmf))
+            if (app.resourceFS->findFile(string("fonts/")+name+".png", png) &&
+                app.resourceFS->findFile(string("fonts/")+name+".bmf", bmf))
             {
-                return px::LoadBitmapFont(png.c_str(), bmf.c_str());
+                return ecl::LoadBitmapFont(png.c_str(), bmf.c_str());
             }
             return 0;
         }
 
         Font *load_ttf (const string &name, int ptsize, int r, int g, int b) {
             string ttf;
-            if (enigma::FindFile (string("fonts/") + name, ttf))
-                return px::LoadTTF (ttf.c_str(), ptsize, r, g, b);
+            if (app.resourceFS->findFile(string("fonts/") + name, ttf))
+                return ecl::LoadTTF (ttf.c_str(), ptsize, r, g, b);
             return 0;
         }
 
         // Variables
-        px::Dict <FontDescr> m_fonts;
+        ecl::Dict <FontDescr> m_fonts;
     };
 
     // ---------- Variables ----------
@@ -435,9 +469,9 @@ namespace
     ImageCache image_cache;
 }
 
-Surface *ImageCache::acquire (const std::string &name) 
+ecl::Surface *ImageCache::acquire (const std::string &name) 
 {
-    return px::LoadImage(name.c_str());
+    return ecl::LoadImage(name.c_str());
 }
 
 void enigma::DefineFont (const char *name, 
@@ -449,28 +483,28 @@ void enigma::DefineFont (const char *name,
     font_cache.define_font (FontDescr (name, ttf_name, ttf_size, bmf_name, r, g, b));
 }
 
-px::Font *enigma::GetFont (const char *name) 
+ecl::Font *enigma::GetFont (const char *name) 
 {
     return font_cache.get(name);
 }
 
-px::Surface *enigma::LoadImage(const char *name) 
+ecl::Surface *enigma::LoadImage(const char *name) 
 {
     string filename;
-    if (file::FindImageFile (string(name) + ".png", filename)) 
-        return px::LoadImage(filename.c_str());
+    if (app.resourceFS->findImageFile (string(name) + ".png", filename)) 
+        return ecl::LoadImage(filename.c_str());
     return 0;
 }
 
-px::Surface *enigma::GetImage(const char *name, const char *ext) 
+ecl::Surface *enigma::GetImage(const char *name, const char *ext) 
 {
     string filename;
-    if (file::FindImageFile (string(name) + ext, filename)) 
+    if (app.resourceFS->findImageFile (string(name) + ext, filename)) 
         return image_cache.get(filename);
     return 0;
 }
 
-px::Surface *enigma::RegisterImage (const char *name, px::Surface *s) 
+ecl::Surface *enigma::RegisterImage (const char *name, ecl::Surface *s) 
 {
     image_cache.store(name, s);
     return s;
