@@ -21,12 +21,13 @@
 #include "errors.hh"
 #include "main.hh"
 #include "options.hh"
-#include "oxyd.hh"
+#include "sound.hh"
 #include "PreferenceManager.hh"
 #include "StateManager.hh"
 #include "lev/ScoreManager.hh"
 #include "lev/RatingManager.hh"
 
+#include <cstdio>
 
 namespace enigma { namespace lev {
 
@@ -52,7 +53,8 @@ namespace enigma { namespace lev {
             return;
         
         // check for uniqueness of index name
-        
+        if (findIndex(anIndex->getName()) != NULL)
+            return;
             
         indices.insert(std::make_pair(anIndex->getName(), anIndex));
         
@@ -111,6 +113,7 @@ namespace enigma { namespace lev {
             for (itg = indexGroups.begin(); itg != indexGroups.end(); itg++)
                 addIndexToGroup(anIndex, (*itg).second);
         }
+        return;
     }
     
     void Index::addIndexToGroup(Index *anIndex, std::vector<Index *> * aGroup) {
@@ -323,7 +326,7 @@ namespace enigma { namespace lev {
         Index * newIndex = findIndex(anIndexName);
         if (newIndex != NULL) {
             if (newIndex != currentIndex) {
-                oxyd::ChangeSoundset(newIndex->get_default_SoundSet(), true);
+                sound::SetDefaultSoundSet(newIndex->get_default_SoundSet());
                 currentIndex = newIndex;
                 std::string group = currentIndex->getGroupName();
                 if (group != INDEX_EVERY_GROUP && 
@@ -703,8 +706,8 @@ namespace enigma { namespace lev {
     
 
     /*! Return the default SoundSet (see options::SoundSet for meaning) */
-    int Index::get_default_SoundSet() const { 
-        return 1;
+    const char* Index::get_default_SoundSet() const { 
+        return "Enigma";
     }
 
     /*! Returns true if it's a twoplayer levelpack, but has no
