@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2002,2003 Daniel Heck
+ * Copyright (C) 2002,2003,2005 Daniel Heck
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -13,76 +13,105 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: options.cc,v 1.31 2004/03/15 20:15:35 dheck Exp $
  */
-#ifdef __MINGW32__
-#       include <windows.h>
-#endif
+#include "errors.hh"
 #include "lua.hh"
 #include "main.hh"
 #include "options.hh"
+#include "PreferenceManager.hh"
 #include "sound.hh"
-#include "px/system.hh"
+#include "ecl_system.hh"
 
 #include <cassert>
 #include <cstdio>
 #include <cstdlib>
 #include <set>
 
+#ifndef CXXLUA
 extern "C" {
 #include <lua.h>
+#include <lauxlib.h>
 }
+#else
+#include <lua.h>
+#include <lauxlib.h>
+#endif 
+
+#ifdef __MINGW32__
+#       include <windows.h>
+#endif
 
 using namespace enigma;
 
+
+/* -------------------- LevelStatus implementation -------------------- */
+
+namespace enigma_options
+{
+    LevelStatus::LevelStatus(int easy, int hard, int finished_, int solved_rev)
+        : time_easy (easy),
+          time_hard (hard),
+          finished (finished_),
+          solved_revision (solved_rev) {
+    }
+
+    bool LevelStatus::operator == (const LevelStatus& other) const  {
+        return (time_easy == other.time_easy &&
+                time_hard == other.time_hard &&
+                finished == other.finished &&
+                solved_revision == other.solved_revision);
+    }
+}
 
 /* -------------------- Variables -------------------- */
 
 namespace enigma_options
 {
     bool LevelStatusChanged = false;
-    bool MustRestart        = false;
-    bool MustRestartLevel   = false;
+//    bool MustRestart        = false;
+//    bool MustRestartLevel   = false;
 }
 
 
 /* -------------------- Functions -------------------- */
 
+bool options::HasOption (const char *name, std::string &value) {
+    bool hasOption;
+    const char * result;
+    lua_State *L = lua::GlobalState();
+    lua_getglobal (L, "options");
+    lua_pushstring (L, name);
+    lua_rawget (L, -2);
+    result = lua_tostring (L, -1);
+    if (result != NULL) {
+        hasOption = true;
+        value = result;
+    } else {
+        hasOption = false;
+    }
+    lua_pop (L, 2);
+    return hasOption;
+} 
+
 void options::SetOption (const char *name, double value)
 {
-    lua_State *L = lua::GlobalState();
-    lua::SetTableVar (L, "options", name, value);
+    app.prefs->setProperty(name, value);
 }
 
 void options::SetOption (const char *name, const std::string &value)
 {
-    lua_State *L = lua::GlobalState();
-    lua_getglobal (L, "options");
-    lua_pushstring (L, name);
-    lua_pushstring (L, value.c_str());
-    lua_rawset (L, -3);
-    lua_pop (L, 1);
+    app.prefs->setProperty(name, value);
 }
 
 void options::GetOption (const char *name, double &value)
 {
-    lua_State *L = lua::GlobalState();
-    lua_getglobal (L, "options");
-    lua_pushstring (L, name);
-    lua_rawget (L, -2);
-    value = lua_tonumber (L, -1);
-    lua_pop(L, 2);
+    app.prefs->getProperty(name, value);
 }
 
 void options::GetOption (const char *name, std::string &value) {
-    lua_State *L = lua::GlobalState();
-    lua_getglobal (L, "options");
-    lua_pushstring (L, name);
-    lua_rawget (L, -2);
-    value = lua_tostring (L, -1);
-    lua_pop (L, 2);
+    app.prefs->getProperty(name, value);
 } 
 
 bool options::GetBool (const char *name) {
@@ -107,7 +136,7 @@ int options::GetInt (const char *name) {
 double options::SetMouseSpeed (double speed) 
 {
     double oldspeed = GetMouseSpeed();
-    double newspeed = px::Clamp<double>(speed, MIN_MouseSpeed, MAX_MouseSpeed);
+    double newspeed = ecl::Clamp<double>(speed, MIN_MouseSpeed, MAX_MouseSpeed);
     SetOption("MouseSpeed", newspeed);
     return oldspeed;
 }
@@ -131,10 +160,8 @@ std::string options::GetString (const char *name)
 }
 
 static void UpdateLevelStatus(const std::string &levelname,
-                              const LevelStatus &stat)
+                              const options::LevelStatus &stat)
 {
-    options::LevelStatusChanged = true;
-
     lua_State *L = lua::GlobalState();
 
     int oldtop = lua_gettop(L);
@@ -161,7 +188,7 @@ bool options::GetLevelStatus (const std::string &levelname,
     lua_getglobal(L, "stats");
     lua_pushstring (L, levelname.c_str());
     lua_rawget (L, -2);
-    if (!lua_istable(L, -1) || !lua_getn(L, -1)==4) {
+    if (!lua_istable(L, -1) || luaL_getn(L, -1)!=4) {
         lua_settop(L, oldtop);
         return false;
     }
@@ -184,23 +211,6 @@ bool options::GetLevelStatus (const std::string &levelname,
 }
 
 
-void
-options::SetLevelStatus(const std::string &levelname,
-                        const LevelStatus &stat)
-{
-    LevelStatus oldstat;
-    if (GetLevelStatus(levelname, oldstat))
-        if (oldstat == stat)
-            return;             // If nothing changed, return
-
-    UpdateLevelStatus(levelname, stat);
-}
-
-int options::GetDifficulty()
-{
-    return GetInt ("Difficulty");
-}
-
 /* Determine name of the user's personal configuration file. */
 static std::string
 Personal_ConfigurationFileName()
@@ -208,7 +218,7 @@ Personal_ConfigurationFileName()
     std::string fname = "enigmarc.lua";
 
     if (getenv ("HOME") != 0)
-        fname = px::ExpandPath ("~/.enigmarc");
+        fname = ecl::ExpandPath ("~/.enigmarc");
 
     return fname;
 }
@@ -216,7 +226,7 @@ Personal_ConfigurationFileName()
 static std::string
 System_ConfigurationFileName()
 {
-    return enigma::FindDataFile ("enigma_conf.lua");
+    return app.systemFS->findFile ("enigma_conf.lua");
 }
 
 #ifdef __MINGW32__
@@ -224,65 +234,23 @@ System_ConfigurationFileName()
 static std::string
 Windows_ConfigurationFileName()
 {
-    typedef HRESULT (WINAPI *SHGETFOLDERPATH)( HWND, int, HANDLE, DWORD, LPTSTR );
-#   define CSIDL_FLAG_CREATE 0x8000
-#   define CSIDL_APPDATA 0x1A
-#   define SHGFP_TYPE_CURRENT 0
-
-    HINSTANCE shfolder_dll;
-    SHGETFOLDERPATH SHGetFolderPath ;
-
-    /* load the shfolder.dll to retreive SHGetFolderPath */
-    if( ( shfolder_dll = LoadLibrary("shfolder.dll") ) != NULL )
-    {
-        SHGetFolderPath = (SHGETFOLDERPATH)GetProcAddress( shfolder_dll, "SHGetFolderPathA");
-        if ( SHGetFolderPath != NULL )
-        {
-            TCHAR szPath[MAX_PATH] = "";
-
-            /* get the "Application Data" folder for the current user */
-            if( S_OK == SHGetFolderPath( NULL, CSIDL_APPDATA | CSIDL_FLAG_CREATE,
-                                         NULL, SHGFP_TYPE_CURRENT, szPath) )
-            {
-                FreeLibrary( shfolder_dll);
-                return std::string(szPath) + "/enigmarc.lua";
-            }
-        }
-        FreeLibrary( shfolder_dll);
-    }
-
-    return Personal_ConfigurationFileName();
-}
-
-#endif
-
-
-bool options::Save ()
-{
-#ifdef __MINGW32__
-    std::string fname;
-    if (!getenv("HOME"))        // if HOME undefined
-        fname    = Windows_ConfigurationFileName();
+    std::string result = ecl::ApplicationDataPath();
+    
+    if (!result.empty()) 
+        return result + "/enigmarc.lua";
     else
-        fname    = Personal_ConfigurationFileName();
-#else
-    std::string fname = Personal_ConfigurationFileName();
-#endif
-
-    if (lua::CallFunc(lua::GlobalState(), "SaveOptions", fname+"2") == 0) {
-        LevelStatusChanged = false;
-        return true;
-    }
+        return Personal_ConfigurationFileName();
     
-    throw enigma_levels::XLevelRuntime(std::string("Calling 'SaveOptions' failed:\n")+lua::LastError(lua::GlobalState()));
-    // return false; // was never used
 }
 
+#endif
+
+
 static bool
 load_from_file (const std::string &fname)
 {
-    int errcode = lua_dofile (lua::GlobalState(), fname.c_str());
-    bool success =  (errcode == 0 || errcode == LUA_ERRFILE);
+    lua::Error errcode = lua::DoAbsoluteFile(lua::GlobalState(), fname.c_str());
+    bool success =  (errcode == 0 || errcode == lua::ERRFILE);
     if (!success) {
         enigma::Log << "error in file `" << fname <<"'\n";
     }
