@@ -14,9 +14,8 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: ox_extra.cc,v 1.1 2004/02/15 11:32:52 dheck Exp $
  */
 
 #if defined(PLAIN_SPEC_ONLY)
@@ -64,7 +63,7 @@ const char *oxyd::oxydextra_floor_map[256] = {
     UNUSED,              // OxydExtra floor 0x14
     UNUSED,              // OxydExtra floor 0x15
     UNUSED,              // OxydExtra floor 0x16
-    "fl-ice_001",        // OxydExtra floor 0x17
+    "fl-ice",            // OxydExtra floor 0x17
     UNUSED,              // OxydExtra floor 0x18
     UNUSED,              // OxydExtra floor 0x19
     UNUSED,              // OxydExtra floor 0x1a
