@@ -14,14 +14,13 @@
  *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write to the Free Software Foundation, Inc.,
- * 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  *
- * $Id: ox_peroxyd.cc,v 1.6 2004/03/18 18:09:24 dheck Exp $
  */
 
 #if defined(PLAIN_SPEC_ONLY)
 // This is used from lib-src/oxydlib/EnigmaNames.cpp.
-// 
+//
 // defining PLAIN_SPEC_ONLY only shows xxx_floor_map, xxx_stone_map and xxx_item_map
 // Note:  the xxx_item_map changes it's type (ItemID -> const char *)
 
@@ -58,7 +57,7 @@ Stone *PerOxydLoader::make_stone (int type, int x, int y)
 }
 
 
-
+
 /* -------------------- Per.Oxyd level pack -------------------- */
 
 LP_PerOxyd::LP_PerOxyd (DatFile *dat, bool twoplayers)
@@ -69,11 +68,11 @@ LP_PerOxyd::LP_PerOxyd (DatFile *dat, bool twoplayers)
 {
 }
 
-void LP_PerOxyd::load (const Level &level)
+void LP_PerOxyd::load (const OxydLib::Level &level)
 {
-    LoaderConfig c (needs_twoplayers(), 
-                    get_gamemode(), 
-                    peroxyd_floor_map, 
+    LoaderConfig c (needs_twoplayers(),
+                    get_gamemode(),
+                    peroxyd_floor_map,
                     peroxyd_item_map,
                     peroxyd_stone_map);
     c.id_timer  = 0x2e;
@@ -81,6 +80,32 @@ void LP_PerOxyd::load (const Level &level)
     PerOxydLoader (level, c).load();
 }
 
+bool LP_PerOxyd::hasEasymode(size_t index) {
+    static const bool easymode_map[200] = { // 1-100 single, 101 - 200 netplay
+        false, false, true,  false, false, false, false, true,  true,  true,  //   1 -  10
+        true,  false, false, true,  false, false, true,  false, false, false, //  11 -  20
+        false, false, false, true,  false, true,  true,  false, true,  true,  //  21 -  30
+        true,  false, true,  true,  false, false, true,  true,  false, true,  //  31 -  40
+        true,  true,  true,  false, true,  false, true,  true,  false, true,  //  41 -  50
+        true,  true,  false, true,  true,  true,  false, true,  false, true,  //  51 -  60
+        true,  false, false, false, true,  false, true,  true,  false, true,  //  61 -  70
+        false, true,  true,  true,  true,  true,  true,  true,  true,  true,  //  71 -  80
+        true,  true,  true,  true,  false, true,  false, true,  true,  true,  //  81 -  90
+        false, true,  false, true,  true,  true,  true,  true,  true,  true,  //  91 - 100
+        false, false, true,  true,  true,  false, false, true,  false, true,  // 101 - 110
+        false, true,  false, true,  true,  true,  false, false, false, false, // 111 - 120
+        true,  false, false, true,  false, false, false, false, true,  false, // 121 - 130
+        false, false, true,  true,  false, true,  false, true,  true,  true,  // 131 - 140
+        false, false, true,  false, false, true,  true,  true,  true,  false, // 141 - 150
+        true,  true,  true,  true,  false, true,  true,  true,  false, false, // 151 - 160
+        true,  true,  true,  true,  true,  true,  false, true,  true,  true,  // 161 - 170
+        false, true,  true,  true,  true,  true,  true,  true,  true,  true,  // 171 - 180
+        false, true,  false, true,  true,  true,  false, true,  false, true,  // 181 - 190
+        false, true,  false, false, true,  true,  true,  true,  true,  true   // 191 - 200
+    };
+    return easymode_map[index];
+} 
+
 #endif // PLAIN_SPEC_ONLY
 // only tables following!
 
@@ -136,19 +161,19 @@ const char *oxyd::peroxyd_floor_map[256] = {
     "fl-gradient14",            // PerOxyd floor 0x30 (flat force)
     "fl-gradient15",            // PerOxyd floor 0x31 (flat force)
     "fl-gradient16",            // PerOxyd floor 0x32 (flat force)
-    0,                          // PerOxyd floor 0x33 (common was 'fl-rough')
+    "fl-rough",                 // PerOxyd floor 0x33 (common was 'fl-rough', should be a 'fl-paper')(only level 75)
     "fl-rough",                 // PerOxyd floor 0x34
     UNUSED,                     // PerOxyd floor 0x35
     UNUSED,                     // PerOxyd floor 0x36
     UNUSED,                     // PerOxyd floor 0x37
-    "fl-concrete",              // PerOxyd floor 0x38
-    0,                          // PerOxyd floor 0x39
+    "fl-concrete",              // PerOxyd floor 0x38 (Tan/green horizontal Grain)
+    "fl-concrete",              // PerOxyd floor 0x39 (Tan/green horizontal Grain, same as 0x38)(only level 118)
     UNUSED,                     // PerOxyd floor 0x3a
     UNUSED,                     // PerOxyd floor 0x3b
     "fl-stwood1",               // PerOxyd floor 0x3c
-    "fl-samba",                 // PerOxyd floor 0x3d (common was 'fl-wood')
-    0,                          // PerOxyd floor 0x3e (common was 'fl-wood')
-    "fl-samba2",                // PerOxyd floor 0x3f
+    "fl-samba",                 // PerOxyd floor 0x3d (common was 'fl-wood', horizontal or vertical slats)(many)
+    "fl-samba1",                // PerOxyd floor 0x3e (common was 'fl-wood', horizontal slats)(only level 32)
+    "fl-samba2",                // PerOxyd floor 0x3f (common was 'fl-wood', vertical slats)(levels: 35, 152)
     UNUSED,                     // PerOxyd floor 0x40
     UNUSED,                     // PerOxyd floor 0x41
     "fl-bumps",                 // PerOxyd floor 0x42
@@ -164,48 +189,48 @@ const char *oxyd::peroxyd_floor_map[256] = {
     "fl-bridge-open",           // PerOxyd floor 0x4c
     UNUSED,                     // PerOxyd floor 0x4d
     "fl-gray",                  // PerOxyd floor 0x4e
-    0,                          // PerOxyd floor 0x4f (flat force)
-    "fl-black",                 // PerOxyd floor 0x50 (flat force)
-    "fl-white",                 // PerOxyd floor 0x51 (flat force)
-    "fl-black",                 // PerOxyd floor 0x52 (flat force)
+    "fl-gradient13",            // PerOxyd floor 0x4f (flat force up, beige)        (maybe gradient22?)
+    "fl-black",                 // PerOxyd floor 0x50 (flat force down, dark olive) (maybe gradient21?)
+    "fl-white",                 // PerOxyd floor 0x51 (flat force left, beige)      (maybe gradient24?)
+    "fl-black",                 // PerOxyd floor 0x52 (flat force right, dark olive)(maybe gradient23?)
     "fl-floor_001",             // PerOxyd floor 0x53
     UNUSED,                     // PerOxyd floor 0x54
     "fl-plank",                 // PerOxyd floor 0x55
     UNUSED,                     // PerOxyd floor 0x56
-    0,                          // PerOxyd floor 0x57
+    "fl-woven_orange",          // PerOxyd floor 0x57 (only used in Link-Level 91, friction (2.5) questionable!)
     UNUSED,                     // PerOxyd floor 0x58
     UNUSED,                     // PerOxyd floor 0x59
     UNUSED,                     // PerOxyd floor 0x5a
     "fl-gravel",                // PerOxyd floor 0x5b
     UNUSED,                     // PerOxyd floor 0x5c
     UNUSED,                     // PerOxyd floor 0x5d
-    0,                          // PerOxyd floor 0x5e
+    "fl-gravel",                // PerOxyd floor 0x5e (same as 0x5b)(only level 192)
     // codes >= 0x5f are unused
 };
 
 const char *oxyd::peroxyd_stone_map[256] = {
     0,                          // PerOxyd stone 0x00 no stone
-    0,0,0,0,0,0,0,0,     // PerOxyd stone 0x01 - 0x08   oxyd stones
-    0,0,0,0,0,0,0,0,     // PerOxyd stone 0x08 - 0x10   oxyd stones
-    "st-likeoxydc",      // PerOxyd stone 0x11
-    "st-plain_break", // PerOxyd stone 0x12   no, should be destructible with hammer
-    "st-rock4",          // PerOxyd stone 0x13
-    "st-beads",          // PerOxyd stone 0x14
+    0,0,0,0,0,0,0,0,            // PerOxyd stone 0x01 - 0x08   oxyd stones
+    0,0,0,0,0,0,0,0,            // PerOxyd stone 0x08 - 0x10   oxyd stones
+    "st-likeoxydc",             // PerOxyd stone 0x11
+    "st-plain_break",           // PerOxyd stone 0x12   no, should be destructible with hammer
+    "st-rock4",                 // PerOxyd stone 0x13
+    "st-beads",                 // PerOxyd stone 0x14
     "st-rock5",                 // PerOxyd stone 0x15
     "st-rock7",                 // PerOxyd stone 0x16
-    0,                          // PerOxyd stone 0x17
+    "st-white1",                // PerOxyd stone 0x17 (Looks a little bit different, but function should be the same.)
     "st-grate1",                // PerOxyd stone 0x18
     UNUSED,                     // PerOxyd stone 0x19
     "st-surprise",              // PerOxyd stone 0x1a
-    0,                          // PerOxyd stone 0x1b
+    "st-chameleon",             // PerOxyd stone 0x1b (levels: 23 142 178 183)
     "st-brick_magic",           // PerOxyd stone 0x1c
-    "st-rock3",                 // PerOxyd stone 0x1d
-    0,                          // PerOxyd stone 0x1e
+    "st-camouflage",            // PerOxyd stone 0x1d (green camouflage piece)(if st-camouflage is implemented, put it in here)
+    "st-camouflage",            // PerOxyd stone 0x1e (green camouflage piece)
     UNUSED,                     // PerOxyd stone 0x1f
     "st-stone2",                // PerOxyd stone 0x20
     "st-greenbrown",            // PerOxyd stone 0x21
-    "st-glass",                 // PerOxyd stone 0x22
-    0,                          // PerOxyd stone 0x23
+    "st-glass",                 // PerOxyd stone 0x22 (semi opaque piece, not really glass)
+    "st-glass",                 // PerOxyd stone 0x23 (must be st-glass, see link level 92)
     "st-plain_break",           // PerOxyd stone 0x24
     "st-bluegray_hole",         // PerOxyd stone 0x25
     "st-plain_move",            // PerOxyd stone 0x26
@@ -216,7 +241,7 @@ const char *oxyd::peroxyd_stone_map[256] = {
     "st-fourswitch",            // PerOxyd stone 0x2b
     "st-key",                   // PerOxyd stone 0x2c
     "st-floppy",                // PerOxyd stone 0x2d
-    "",                         // PerOxyd stone 0x2e
+    "",                         // PerOxyd stone 0x2e (?)
     "st-death",                 // PerOxyd stone 0x2f
     "st-death_invisible",       // PerOxyd stone 0x30
     "st-oneway_black-w",        // PerOxyd stone 0x31
@@ -227,45 +252,45 @@ const char *oxyd::peroxyd_stone_map[256] = {
     "st-oneway_white-e",        // PerOxyd stone 0x36
     "st-oneway_white-n",        // PerOxyd stone 0x37
     "st-oneway_white-s",        // PerOxyd stone 0x38
-    0,                          // PerOxyd stone 0x39 ('st-magic')
-    0,                          // PerOxyd stone 0x3a ('st-magic')
-    0,                          // PerOxyd stone 0x3b ('st-magic')
+    "st-magic",                 // PerOxyd stone 0x39 ('st-magic')
+    "st-magic",                 // PerOxyd stone 0x3a ('st-magic')
+    "st-magic",                 // PerOxyd stone 0x3b ('st-magic')
     "st-actorimpulse",          // PerOxyd stone 0x3c
     "st-actorimpulse_invisible", // PerOxyd stone 0x3d
-    "st-laser-1",        // PerOxyd stone 0x3e  The laser-names are fake names!
-    "st-laser-2",        // PerOxyd stone 0x3f  Direction and state are generated by Enigma.
-    "st-laser-3",        // PerOxyd stone 0x40
-    "st-mirror-p|",      // PerOxyd stone 0x41
-    "st-mirror-p/",      // PerOxyd stone 0x42
-    "st-mirror-p-",      // PerOxyd stone 0x43
-    "st-mirror-p\\",     // PerOxyd stone 0x44
-    UNUSED,              // PerOxyd stone 0x45
-    "st-mirror-p/m",     // PerOxyd stone 0x46
-    "st-mirror-p-m",     // PerOxyd stone 0x47
-    "st-mirror-p\\m",    // PerOxyd stone 0x48
-    "st-mirror-p|t",     // PerOxyd stone 0x49
-    "st-mirror-p/t",     // PerOxyd stone 0x4a
-    "st-mirror-p-t",     // PerOxyd stone 0x4b
-    "st-mirror-p\\t",    // PerOxyd stone 0x4c
-    "st-mirror-3>",      // PerOxyd stone 0x4d
-    "st-mirror-3^",      // PerOxyd stone 0x4e
-    "st-mirror-3<",      // PerOxyd stone 0x4f
-    "st-mirror-3v",      // PerOxyd stone 0x50
-    "st-puzzle-es",      // PerOxyd stone 0x51
-    "st-puzzle-sw",      // PerOxyd stone 0x52
-    "st-puzzle-nw",      // PerOxyd stone 0x53
-    "st-puzzle-ne",      // PerOxyd stone 0x54
-    "st-puzzle-ew",      // PerOxyd stone 0x55
-    "st-puzzle-ns",      // PerOxyd stone 0x56
-    "st-puzzle-n",       // PerOxyd stone 0x57
-    "st-puzzle-s",       // PerOxyd stone 0x58
-    "st-puzzle-w",       // PerOxyd stone 0x59
-    "st-puzzle-e",       // PerOxyd stone 0x5a
-    "st-puzzle-nesw",    // PerOxyd stone 0x5b
+    "st-laser-1",               // PerOxyd stone 0x3e  The laser-names are fake names!
+    "st-laser-2",               // PerOxyd stone 0x3f  Direction and state are generated by Enigma.
+    "st-laser-3",               // PerOxyd stone 0x40
+    "st-mirror-p|",             // PerOxyd stone 0x41
+    "st-mirror-p/",             // PerOxyd stone 0x42
+    "st-mirror-p-",             // PerOxyd stone 0x43
+    "st-mirror-p\\",            // PerOxyd stone 0x44
+    UNUSED,                     // PerOxyd stone 0x45
+    "st-mirror-p/m",            // PerOxyd stone 0x46
+    "st-mirror-p-m",            // PerOxyd stone 0x47
+    "st-mirror-p\\m",           // PerOxyd stone 0x48
+    "st-mirror-p|t",            // PerOxyd stone 0x49
+    "st-mirror-p/t",            // PerOxyd stone 0x4a
+    "st-mirror-p-t",            // PerOxyd stone 0x4b
+    "st-mirror-p\\t",           // PerOxyd stone 0x4c
+    "st-mirror-3>",             // PerOxyd stone 0x4d
+    "st-mirror-3^",             // PerOxyd stone 0x4e
+    "st-mirror-3<",             // PerOxyd stone 0x4f
+    "st-mirror-3v",             // PerOxyd stone 0x50
+    "st-puzzle-es",             // PerOxyd stone 0x51
+    "st-puzzle-sw",             // PerOxyd stone 0x52
+    "st-puzzle-nw",             // PerOxyd stone 0x53
+    "st-puzzle-ne",             // PerOxyd stone 0x54
+    "st-puzzle-ew",             // PerOxyd stone 0x55
+    "st-puzzle-ns",             // PerOxyd stone 0x56
+    "st-puzzle-n",              // PerOxyd stone 0x57
+    "st-puzzle-s",              // PerOxyd stone 0x58
+    "st-puzzle-w",              // PerOxyd stone 0x59
+    "st-puzzle-e",              // PerOxyd stone 0x5a
+    "st-puzzle-nesw",           // PerOxyd stone 0x5b
     "st-puzzle-hollow",         // PerOxyd stone 0x5c
     "st-laserbreak",            // PerOxyd stone 0x5d
     "st-coffee",                // PerOxyd stone 0x5e
-    0,                   // PerOxyd stone 0x5f
+    "st-shogun",                // PerOxyd stone 0x5f (oxyd with a hole, movable ... strange stone! st-shogun as workaround, only link level 74)
     "st-disco-dark",            // PerOxyd stone 0x60
     "st-disco-medium",          // PerOxyd stone 0x61
     "st-bombs",                 // PerOxyd stone 0x62
@@ -287,14 +312,14 @@ const char *oxyd::peroxyd_stone_map[256] = {
     "st-mail-s",                // PerOxyd stone 0x72
     "st-door-h",                // PerOxyd stone 0x73
     "st-door-v",                // PerOxyd stone 0x74
-    "st-rock2",                 // PerOxyd stone 0x75 looks like a white version of st-rock2 (common was 'st-rock2')
+    "st-metal",                 // PerOxyd stone 0x75
     "st-stonebrush",            // PerOxyd stone 0x76
     "st-door-h-open",           // PerOxyd stone 0x77
     "st-door-v-open",           // PerOxyd stone 0x78
-    "st-white1",         // PerOxyd stone 0x79 (Can be either st-white1 or st-white4)
-    "st-black1",         // PerOxyd stone 0x7a (Can be either st-black1 or st-black4)
-    0,                   // PerOxyd stone 0x7b
-    0,                   // PerOxyd stone 0x7c
+    "st-white1",                // PerOxyd stone 0x79 (Can be either st-white1 or st-white4)
+    "st-black1",                // PerOxyd stone 0x7a (Can be either st-black1 or st-black4)
+    "st-metal_hole",            // PerOxyd stone 0x7b (because it looks similar ...; only link level 79)
+    0,                          // PerOxyd stone 0x7c (probably complex stone, behavior unknown)(only levels: 23 142, these levels are identical!)
     "st-yinyang3",              // PerOxyd stone 0x7d
     "st-break_acwhite",         // PerOxyd stone 0x7e
     "st-break_acblack",         // PerOxyd stone 0x7f
@@ -311,21 +336,21 @@ const char *oxyd::peroxyd_stone_map[256] = {
     "st-rock6",                 // PerOxyd stone 0x8a
     "st-blue-sand",             // PerOxyd stone 0x8b
     "st-rock1",                 // PerOxyd stone 0x8c
-    0,                          // PerOxyd stone 0x8d
-    "st-metal",                 // PerOxyd stone 0x8e
+    "st-rock2",                 // PerOxyd stone 0x8d (simple border stone, not exactly st-rock2 ...; only link level 92)
+    "st-rock2",                 // PerOxyd stone 0x8e
     UNUSED,                     // PerOxyd stone 0x8f
     "st-rock8",                 // PerOxyd stone 0x90
-    "st-rotator_move-left",  // PerOxyd stone 0x91
-    "st-rotator_move-right", // PerOxyd stone 0x92
-    "st-swap",           // PerOxyd stone 0x93
-    "st-spitter",        // PerOxyd stone 0x94
-    0,                   // PerOxyd stone 0x95 dynamite 
-    "st-rubberband",     // PerOxyd stone 0x96
-    "st-scissors",       // PerOxyd stone 0x97
-    "st-grate3",         // PerOxyd stone 0x98
-    "st-blocker",        // PerOxyd stone 0x99
-    "st-grate1",         // PerOxyd stone 0x9a
-    "st-rock2_hole",            // PerOxyd stone 0x9b
+    "st-rotator_move-left",     // PerOxyd stone 0x91
+    "st-rotator_move-right",    // PerOxyd stone 0x92
+    "st-swap",                  // PerOxyd stone 0x93
+    "st-spitter",               // PerOxyd stone 0x94
+    0,                          // PerOxyd stone 0x95 (dynamite holder, will implememnt it)(levels: 41 184 200)
+    "st-rubberband",            // PerOxyd stone 0x96
+    "st-scissors",              // PerOxyd stone 0x97
+    "st-grate3",                // PerOxyd stone 0x98
+    "st-blocker",               // PerOxyd stone 0x99
+    "st-grate1",                // PerOxyd stone 0x9a
+    "st-metal_hole",            // PerOxyd stone 0x9b
     "st-stone1",                // PerOxyd stone 0x9c
     "st-fart",                  // PerOxyd stone 0x9d
     "st-turnstile",             // PerOxyd stone 0x9e
@@ -335,25 +360,25 @@ const char *oxyd::peroxyd_stone_map[256] = {
     "st-turnstile-e",           // PerOxyd stone 0xa2
     UNUSED,                     // PerOxyd stone 0xa3
     "st-likeoxydc",             // PerOxyd stone 0xa4 laserswitch on
-    UNUSED,              // PerOxyd stone 0xa5
-    UNUSED,              // PerOxyd stone 0xa6
-    UNUSED,              // PerOxyd stone 0xa7
-    UNUSED,              // PerOxyd stone 0xa8
-    UNUSED,              // PerOxyd stone 0xa9
-    UNUSED,              // PerOxyd stone 0xaa
-    UNUSED,              // PerOxyd stone 0xab
-    UNUSED,              // PerOxyd stone 0xac
-    UNUSED,              // PerOxyd stone 0xad
-    UNUSED,              // PerOxyd stone 0xae
-    UNUSED,              // PerOxyd stone 0xaf
-    UNUSED,              // PerOxyd stone 0xb0
-    UNUSED,              // PerOxyd stone 0xb1
-    UNUSED,              // PerOxyd stone 0xb2
-    UNUSED,              // PerOxyd stone 0xb3
-    UNUSED,              // PerOxyd stone 0xb4
-    UNUSED,              // PerOxyd stone 0xb5
-    UNUSED,              // PerOxyd stone 0xb6
-    "st-easymode",       // PerOxyd stone 0xb7
+    UNUSED,                     // PerOxyd stone 0xa5
+    UNUSED,                     // PerOxyd stone 0xa6
+    UNUSED,                     // PerOxyd stone 0xa7
+    UNUSED,                     // PerOxyd stone 0xa8
+    UNUSED,                     // PerOxyd stone 0xa9
+    UNUSED,                     // PerOxyd stone 0xaa
+    UNUSED,                     // PerOxyd stone 0xab
+    UNUSED,                     // PerOxyd stone 0xac
+    UNUSED,                     // PerOxyd stone 0xad
+    UNUSED,                     // PerOxyd stone 0xae
+    UNUSED,                     // PerOxyd stone 0xaf
+    UNUSED,                     // PerOxyd stone 0xb0
+    UNUSED,                     // PerOxyd stone 0xb1
+    UNUSED,                     // PerOxyd stone 0xb2
+    UNUSED,                     // PerOxyd stone 0xb3
+    UNUSED,                     // PerOxyd stone 0xb4
+    UNUSED,                     // PerOxyd stone 0xb5
+    UNUSED,                     // PerOxyd stone 0xb6
+    "st-easymode",              // PerOxyd stone 0xb7
     "st-peroxyd-0xb8",          // PerOxyd stone 0xb8
     "st-peroxyd-0xb9",          // PerOxyd stone 0xb9
     // codes >= 0xba are unused
@@ -370,7 +395,7 @@ ITEMMAPTYPE oxyd::peroxyd_item_map[256] = {
     ITEMSPEC(it_cherry),                  // 0x06
     ITEMSPEC(it_umbrella),                // 0x07
     ITEMSPEC(it_glasses),                 // 0x08
-    ITEMSPEC(it_glasses_broken),          // 0x09 
+    ITEMSPEC(it_glasses_broken),          // 0x09
     ITEMSPEC(it_dynamite),                // 0x0a
     ITEMSPEC(it_blackbomb),               // 0x0b
     ITEMSPEC(it_whitebomb),               // 0x0c
@@ -427,7 +452,7 @@ ITEMMAPTYPE oxyd::peroxyd_item_map[256] = {
     ITEMSPEC(it_changefloor),             // 0x3f
     ITEMSPEC(it_trigger),                 // 0x40
     ITEMSPEC(it_brush),                   // 0x41
-    ITEMSPEC(it_banana),                  // 0x42 
+    ITEMSPEC(it_banana),                  // 0x42
     ITEMSPEC(it_pencil),                  // 0x43
     ITEMSPEC(it_brake),                   // 0x44
     ITEMSPEC(it_squashed),                // 0x45
@@ -481,7 +506,7 @@ ITEMMAPTYPE oxyd::peroxyd_item_map[256] = {
     ITEMSPEC(it_UNUSED),                  // 0x75
     ITEMSPEC(it_easykillstone),           // 0x76
     ITEMSPEC(it_easykeepstone),           // 0x77
-    ITEMSPEC(it_2pkillstone),             // 0x78 
+    ITEMSPEC(it_2pkillstone),             // 0x78
     ITEMSPEC(it_1pkillstone),             // 0x79
     // codes >= 0x7a are unused
 };
