@@ -502,6 +502,7 @@ void World::tick (double dtime)
 
     move_actors (dtime);
     handle_delayed_impulses (dtime);
+    tick_sound_dampings();
 
     // Tell floors and items about new stones.
     for (unsigned i=0; i<changed_stones.size(); ++i)
@@ -757,6 +758,7 @@ void World::find_contact_with_stone (Actor *a, GridPos p, StoneContact &c)
         c.ignore   = false;
         c.actor    = a;
         c.stonepos = p;
+	c.stoneid  = stone->get_traits().id;
         c.response = stone->collision_response(c);
         c.sound    = stone->collision_sound();
     }
@@ -804,7 +806,7 @@ void World::handle_stone_contact (StoneContact &sc)
     ActorInfo &ai          = *a->get_actorinfo();
     double     restitution = 1.0; //0.85;
 
-    if (server::NoCollisions)
+    if (server::NoCollisions  && (sc.stoneid != st_borderstone))
         return;
 
     Contact contact (sc.contact_point, sc.normal);
@@ -827,7 +829,8 @@ void World::handle_stone_contact (StoneContact &sc)
                         client::Msg_Sparkle (sc.contact_point);
                         double volume = std::max (0.25, length(ai.vel)/8);
                         volume = std::min (1.0, volume);
-                        sound::SoundEvent (sc.sound.c_str(), sc.contact_point, volume);
+                        volume = getVolume(sc.sound.c_str(), a, volume);
+                        sound::EmitSoundEvent (sc.sound.c_str(), sc.contact_point, volume);
                     }
                 }
             }
@@ -921,8 +924,10 @@ void World::handle_actor_contact (size_t i, size_t j)
             if (!has_nearby_contact (a1.contacts, contact)) {
                 double volume = length (force) * ActorTimeStep;
                 volume = std::min(1.0, volume);
-                if (volume > 0.4)
-                    sound::SoundEvent ("ballcollision", contact.pos, volume);
+                if (volume > 0.4) {
+                    volume = getVolume("ballcollision", NULL, volume);
+                    sound::EmitSoundEvent ("ballcollision", contact.pos, volume);
+                }
             }
         }
     }
@@ -1044,8 +1049,9 @@ void World::handle_delayed_impulses (double dtime)
     while (i != end) {
         // shall the impulse take effect now ?
         if (i->tick(dtime)) {
+            i->mark_referenced(true);
             if (Stone *st = GetStone(i->destination()))
-                i->send_impulse(st);
+                i->send_impulse(st);  // may delete stones and revoke delayed impuleses!
             i = delayed_impulses.erase(i);
         }
         else
@@ -1053,6 +1059,44 @@ void World::handle_delayed_impulses (double dtime)
     }
 }
 
+void World::revoke_delayed_impulses(const Stone *target) {
+    // Revokes delayed impulses to and from target
+    ImpulseList::iterator i = delayed_impulses.begin(),
+        end = delayed_impulses.end();
+    while (i != end) {
+        if (i->is_receiver(target) || i->is_sender(target)) {
+            if (i->is_referenced()) {
+                i->mark_obsolete();
+                ++i;
+            } else {
+                i = delayed_impulses.erase(i);
+            }
+        } else {
+            ++i;
+        }
+    }
+}
+
+void World::tick_sound_dampings ()
+{
+    // See sound.hh and sound.cc for details.
+    static int counter = 0;
+    ++counter;
+
+    if (counter > 9) {
+        counter = 0;
+        SoundDampingList::iterator i = level->sound_dampings.begin(),
+            end = level->sound_dampings.end();
+        int count = 0;
+        while (i != end) {
+            if(i->tick()) // return true if damping entry should be deleted
+                i = level->sound_dampings.erase(i);
+            else
+                ++i;
+        }
+    }
+}
+
 void World::stone_change(GridPos p) 
 {
     if (const Field *f = GetField (p)) {
@@ -1644,6 +1688,8 @@ void world::KillActor (Actor *a) {
 void world::WarpActor(Actor *a, double newx, double newy, bool keep_velocity)
 {
     V2 newpos = V2(newx, newy);
+    ASSERT(IsInsideLevel(GridPos(newpos)), XLevelRuntime,
+        "WarpActor: Tried to warp actor out of level grid. (And hyperspace travel is not implemented yet, sorry.)");
     if (!keep_velocity)
         a->get_actorinfo()->vel = V2();
     a->warp(newpos);
@@ -1768,6 +1814,29 @@ void world::addDelayedImpulse (const Impulse& impulse, double delay,
     level->delayed_impulses.push_back(DelayedImpulse(impulse, delay, estimated_receiver));
 }
 
+void world::revokeDelayedImpulses(const Stone *target) {
+    // Any stone may call this function on deletion.
+    // When the repository shuts down no world is existing thus check
+    // world first.
+    if (level.get() != NULL) 
+        level->revoke_delayed_impulses(target);
+}
+
+float world::getVolume(const char *name, Object *obj, float def_volume)
+{
+    // See sound.hh and sound.cc for details.
+    SoundDampingList::iterator i = level->sound_dampings.begin(),
+        end = level->sound_dampings.end();
+    while (i != end) {
+        if (i->is_equal(name, obj))
+            return i->get_volume(def_volume);
+        ++i;
+    }
+    // No entry found for this object. Create a new one.
+    level->sound_dampings.push_back(sound::SoundDamping(name, obj));
+    return def_volume;
+}
+
 void world::Tick(double dtime) {
     level->tick (dtime);
 }
@@ -1950,13 +2019,13 @@ Object * world::MakeObject(const char *kind) {
     if (last_templ)
         o=last_templ->clone();
     if (!o)
-        fprintf(stderr, "MakeObject: unkown object name `%s'\n",kind);
+        fprintf(stderr, "MakeObject: unknown object name `%s'\n",kind);
     return o;
 }
 
 Object * world::GetObjectTemplate(const std::string &kind) {
     if (!repos->has_templ(kind)) {
-        cerr << "GetObjectTemplate: unkown object name `" <<kind<< "'.\n";
+        cerr << "GetObjectTemplate: unknown object name `" <<kind<< "'.\n";
         return 0;
     } else
         return repos->get_template(kind);
